==> kubernetes-model-autoscaling-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta1/ObjectMetricSourceBuilder.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ObjectMetricSourceBuilder extends io.fabric8.kubernetes.api.model.autoscaling.v2beta1.ObjectMetricSourceFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.ObjectMetricSourceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.ObjectMetricSource,io.fabric8.kubernetes.api.model.autoscaling.v2beta1.ObjectMetricSourceBuilder>{
  public ObjectMetricSourceBuilder() {
    this(false);
  }
  public ObjectMetricSourceBuilder(java.lang.Boolean validationEnabled) {
    this(new ObjectMetricSource(), validationEnabled);
  }
  public ObjectMetricSourceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.ObjectMetricSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public ObjectMetricSourceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.ObjectMetricSourceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ObjectMetricSource(), validationEnabled);
  }
  public ObjectMetricSourceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.ObjectMetricSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta1.ObjectMetricSource instance) {
    this(fluent, instance, false);
  }
  public ObjectMetricSourceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.ObjectMetricSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta1.ObjectMetricSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAverageValue(instance.getAverageValue()); 
    fluent.withMetricName(instance.getMetricName()); 
    fluent.withSelector(instance.getSelector()); 
    fluent.withTarget(instance.getTarget()); 
    fluent.withTargetValue(instance.getTargetValue()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ObjectMetricSourceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.ObjectMetricSource instance) {
    this(instance,false);
  }
  public ObjectMetricSourceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.ObjectMetricSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAverageValue(instance.getAverageValue()); 
    this.withMetricName(instance.getMetricName()); 
    this.withSelector(instance.getSelector()); 
    this.withTarget(instance.getTarget()); 
    this.withTargetValue(instance.getTargetValue()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.autoscaling.v2beta1.ObjectMetricSourceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.ObjectMetricSource build() {
    ObjectMetricSource buildable = new ObjectMetricSource(fluent.getAverageValue(),fluent.getMetricName(),fluent.getSelector(),fluent.getTarget(),fluent.getTargetValue());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ObjectMetricSourceBuilder that = (ObjectMetricSourceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-autoscaling-6.3.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta1/ObjectMetricSourceBuilder.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ObjectMetricSourceBuilder extends ObjectMetricSourceFluentImpl<ObjectMetricSourceBuilder> implements VisitableBuilder<ObjectMetricSource,ObjectMetricSourceBuilder>{
  public ObjectMetricSourceBuilder() {
    this(false);
  }
  public ObjectMetricSourceBuilder(Boolean validationEnabled) {
    this(new ObjectMetricSource(), validationEnabled);
  }
  public ObjectMetricSourceBuilder(ObjectMetricSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public ObjectMetricSourceBuilder(ObjectMetricSourceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ObjectMetricSource(), validationEnabled);
  }
  public ObjectMetricSourceBuilder(ObjectMetricSourceFluent<?> fluent,ObjectMetricSource instance) {
    this(fluent, instance, false);
  }
  public ObjectMetricSourceBuilder(ObjectMetricSourceFluent<?> fluent,ObjectMetricSource instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAverageValue(instance.getAverageValue()); 
    fluent.withMetricName(instance.getMetricName()); 
    fluent.withSelector(instance.getSelector()); 
    fluent.withTarget(instance.getTarget()); 
    fluent.withTargetValue(instance.getTargetValue()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ObjectMetricSourceBuilder(ObjectMetricSource instance) {
    this(instance,false);
  }
  public ObjectMetricSourceBuilder(ObjectMetricSource instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAverageValue(instance.getAverageValue()); 
    this.withMetricName(instance.getMetricName()); 
    this.withSelector(instance.getSelector()); 
    this.withTarget(instance.getTarget()); 
    this.withTargetValue(instance.getTargetValue()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ObjectMetricSourceFluent<?> fluent;
  Boolean validationEnabled;
  public ObjectMetricSource build() {
    ObjectMetricSource buildable = new ObjectMetricSource(fluent.getAverageValue(),fluent.getMetricName(),fluent.getSelector(),fluent.getTarget(),fluent.getTargetValue());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
